@@ -2,9 +2,7 @@
 //
 // The HPI Driver for the Core Audio Engine component of Rivendell
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: cae_hpi.cpp,v 1.38.6.2 2012/11/30 16:14:58 cvs Exp $
+//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -33,7 +31,7 @@ void MainObject::hpiInit(RDStation *station)
       play[i][j]=NULL;
     }
   }
-  sound_card=new RDHPISoundCard(this,"sound_card");
+  sound_card=new RDHPISoundCard(this);
   sound_card->setFadeProfile(RD_FADE_TYPE);
   for(int i=0;i<sound_card->getCardQuantity();i++) {
     cae_driver[i]=RDStation::Hpi;
