@@ -2,10 +2,7 @@
 //
 // An RDCatch event copier.
 //
-//   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdcatch_copy.cpp,v 1.8 2010/07/29 19:32:32 cvs Exp $
-//      $Date: 2010/07/29 19:32:32 $
+//   (C) Copyright 2002-2005,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -33,8 +30,8 @@
 #include <rdcmd_switch.h>
 #include <rddb.h>
 
-MainObject::MainObject(QObject *parent,const char *name)
-  : QObject(parent,name)
+MainObject::MainObject(QObject *parent)
+  : QObject(parent)
 {
   bool found=false;
   QString src_hostname;
@@ -330,6 +327,6 @@ MainObject::MainObject(QObject *parent,const char *name)
 int main(int argc,char *argv[])
 {
   QApplication a(argc,argv,false);
-  new MainObject(NULL,"main");
+  new MainObject(NULL);
   return a.exec();
 }
