@@ -2,9 +2,7 @@
 //
 // Export a Rivendell Report to CBSI DeltaFlex
 //
-//   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: export_deltaflex.cpp,v 1.8 2007/10/04 20:53:27 dmills Exp $
+//   (C) Copyright 2002-2005,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -51,7 +49,7 @@ bool RDReport::ExportDeltaflex(const QDate &startdate,const QDate &enddate,
 #endif
 
   QFile file(filename);
-  if((f=fopen((const char *)filename,"w"))==NULL) {
+  if((f=fopen((const char *)filename,"wb"))==NULL) {
     report_error_code=RDReport::ErrorCantOpen;
     return false;
   }
@@ -111,6 +109,7 @@ bool RDReport::ExportDeltaflex(const QDate &startdate,const QDate &enddate,
   QString tfc_cartnum;
   QString ext_data;
   QString ext_annc_type;
+
   while(q->next()) {
     if(q->value(9).toString().length()>29) {
       cart_title=q->value(9).toString().left(29);
@@ -126,11 +125,16 @@ bool RDReport::ExportDeltaflex(const QDate &startdate,const QDate &enddate,
     }
     ext_data="";
     if(q->value(6).toString().length()>0) {
-      for(unsigned i=0;i<(8-q->value(6).toString().stripWhiteSpace().length());
-	  i++) {
-	ext_data+="0";
+      if(q->value(6).toString().length()<=8) {
+	for(unsigned i=0;i<(8-q->value(6).toString().stripWhiteSpace().length());
+	    i++) {
+	  ext_data+="0";
+	}
+	ext_data+=q->value(6).toString().stripWhiteSpace();
+      }
+      else {
+	ext_data+=q->value(6).toString().stripWhiteSpace().left(8);
       }
-      ext_data+=q->value(6).toString().stripWhiteSpace();
     }
     if(q->value(0).toUInt()<=999000) {
       play_length=QString().sprintf("%03u",q->value(0).toUInt()/1000);
