@@ -113,18 +113,10 @@
         <source>Close Bracket</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>ChainTo</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Track</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Link</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Relative</source>
         <translation type="unfinished"></translation>
@@ -453,6 +445,18 @@
         <source>NoTime</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>MusicLink</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>TrafficLink</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Chain</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDAddCart</name>
