@@ -121,7 +121,7 @@
     </message>
     <message>
         <source>ChainTo</source>
-        <translation type="unfinished">LenkTil</translation>
+        <translation type="obsolete">LenkTil</translation>
     </message>
     <message>
         <source>Track</source>
@@ -129,7 +129,7 @@
     </message>
     <message>
         <source>Link</source>
-        <translation type="unfinished">Lenkje</translation>
+        <translation type="obsolete">Lenkje</translation>
     </message>
     <message>
         <source>Traffic</source>
@@ -467,6 +467,18 @@
         <source>NoTime</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>MusicLink</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>TrafficLink</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Chain</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDAddCart</name>
