@@ -2,9 +2,7 @@
 //
 // A widget to set an integer value.
 //
-//   (C) Copyright 2008 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdintegerdialog.cpp,v 1.3 2010/07/29 19:32:33 cvs Exp $
+//   (C) Copyright 2008,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -26,8 +24,8 @@
 #include <rdintegerdialog.h>
 
 RDIntegerDialog::RDIntegerDialog(int *value,const QString &lbl,int low,int high,
-				 QWidget *parent,const char *name)
-  : QDialog(parent,name,false)
+				 QWidget *parent)
+  : QDialog(parent,"",false)
 {
   int_value=value;
 
