@@ -48,6 +48,9 @@
 #define RDXPORT_COMMAND_ASSIGNSCHEDCODE 25
 #define RDXPORT_COMMAND_UNASSIGNSCHEDCODE 26
 #define RDXPORT_COMMAND_LISTCARTSCHEDCODES 27
+#define RDXPORT_COMMAND_SAVELOG 28
+#define RDXPORT_COMMAND_ADDLOG 29
+#define RDXPORT_COMMAND_DELETELOG 30
 
 
 #endif  // RDXPORT_INTERFACE_H
