@@ -2,9 +2,7 @@
 //
 // Edit a Rivendell Report
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: edit_report.cpp,v 1.21.8.1.2.1 2014/05/22 01:21:36 cvs Exp $
+//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -41,9 +39,8 @@
 #include <autofill_carts.h>
 #include <edit_svc_perms.h>
 
-
-EditReport::EditReport(QString rptname,QWidget *parent,const char *name)
-  : QDialog(parent,name,true)
+EditReport::EditReport(QString rptname,QWidget *parent)
+  : QDialog(parent,"",true)
 {
   QString sql;
   RDSqlQuery *q;
@@ -128,9 +125,7 @@ EditReport::EditReport(QString rptname,QWidget *parent,const char *name)
   edit_cartzeros_box->setGeometry(170,75,15,15);
   connect(edit_cartzeros_box,SIGNAL(toggled(bool)),
 	  this,SLOT(leadingZerosToggled(bool)));
-  label=new QLabel(edit_cartzeros_box,
-		   tr("Use Leading Zeros"),this,
-		   "edit_cartzeros_label");
+  label=new QLabel(edit_cartzeros_box,tr("Use Leading Zeros"),this);
   label->setGeometry(187,73,120,19);
   label->setFont(check_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
@@ -204,14 +199,36 @@ EditReport::EditReport(QString rptname,QWidget *parent,const char *name)
   label->setFont(font);
   label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
 
+  //
+  // Linux Post Export Command
+  //
+  edit_postexport_cmd_edit=new QLineEdit(this);
+  edit_postexport_cmd_edit->setGeometry(170,178,sizeHint().width()-180,19);
+  edit_postexport_cmd_edit->setValidator(validator);
+  label=new QLabel(edit_path_edit,tr("Linux Post Export Cmd:"),this);
+  label->setGeometry(10,178,155,19);
+  label->setFont(font);
+  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+
   //
   // Windows Export Path
   //
   edit_winpath_edit=new QLineEdit(this);
-  edit_winpath_edit->setGeometry(170,178,sizeHint().width()-180,19);
+  edit_winpath_edit->setGeometry(170,199,sizeHint().width()-180,19);
   edit_winpath_edit->setMaxLength(255);
   label=new QLabel(edit_winpath_edit,tr("Windows Export Path:"),this);
-  label->setGeometry(10,178,155,19);
+  label->setGeometry(10,199,155,19);
+  label->setFont(font);
+  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+
+  //
+  // Windows Post Export Command
+  //
+  edit_winpostexport_cmd_edit=new QLineEdit(this);
+  edit_winpostexport_cmd_edit->setGeometry(170,219,sizeHint().width()-180,19);
+  edit_winpostexport_cmd_edit->setValidator(validator);
+  label=new QLabel(edit_path_edit,tr("Windows Post Export Cmd:"),this);
+  label->setGeometry(10,219,155,19);
   label->setFont(font);
   label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
 
@@ -219,28 +236,28 @@ EditReport::EditReport(QString rptname,QWidget *parent,const char *name)
   // Type Selectors
   //
   label=new QLabel(tr("Export Event Types:"),this);
-  label->setGeometry(10,199,155,19);
+  label->setGeometry(10,240,155,19);
   label->setFont(font);
   label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
 
   edit_traffic_box=new QCheckBox(this);
-  edit_traffic_box->setGeometry(170,200,15,15);
+  edit_traffic_box->setGeometry(170,242,15,15);
   edit_traffic_label=new QLabel(tr("Traffic"),this);
-  edit_traffic_label->setGeometry(187,199,80,19);
+  edit_traffic_label->setGeometry(187,241,80,19);
   edit_traffic_label->setFont(check_font);
   edit_traffic_label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
   
   edit_music_box=new QCheckBox(this);
-  edit_music_box->setGeometry(270,201,15,15);
+  edit_music_box->setGeometry(270,243,15,15);
   edit_music_label=new QLabel(tr("Music"),this);
-  edit_music_label->setGeometry(287,199,80,19);
+  edit_music_label->setGeometry(287,241,80,19);
   edit_music_label->setFont(check_font);
   edit_music_label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
   edit_generic_box=new QCheckBox(this);
-  edit_generic_box->setGeometry(370,201,15,15);
+  edit_generic_box->setGeometry(370,243,15,15);
   label=new QLabel(tr("All"),this);
-  label->setGeometry(387,199,80,19);
+  label->setGeometry(387,241,80,19);
   label->setFont(check_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
   connect(edit_generic_box,SIGNAL(toggled(bool)),
@@ -250,21 +267,21 @@ EditReport::EditReport(QString rptname,QWidget *parent,const char *name)
   // Force Event Source Selectors
   //
   label=new QLabel(tr("Export Events From:"),this);
-  label->setGeometry(10,220,155,19);
+  label->setGeometry(10,262,155,19);
   label->setFont(font);
   label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
 
   edit_forcetraffic_box=new QCheckBox(this);
-  edit_forcetraffic_box->setGeometry(170,222,15,15);
+  edit_forcetraffic_box->setGeometry(170,264,15,15);
   label=new QLabel(tr("Traffic Log"),this);
-  label->setGeometry(187,220,80,19);
+  label->setGeometry(187,262,80,19);
   label->setFont(check_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
   
   edit_forcemusic_box=new QCheckBox(this);
-  edit_forcemusic_box->setGeometry(270,222,15,15);
+  edit_forcemusic_box->setGeometry(270,264,15,15);
   label=new QLabel(tr("Music Log"),this);
-  label->setGeometry(287,220,80,19);
+  label->setGeometry(287,262,80,19);
   label->setFont(check_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
@@ -272,11 +289,11 @@ EditReport::EditReport(QString rptname,QWidget *parent,const char *name)
   // Include Only On Air Events
   //
   edit_onairflag_box=new QComboBox(this);
-  edit_onairflag_box->setGeometry(170,241,60,19);
+  edit_onairflag_box->setGeometry(170,283,60,19);
   edit_onairflag_box->insertItem(tr("No"));
   edit_onairflag_box->insertItem(tr("Yes"));
   label=new QLabel(edit_onairflag_box,tr("Include Only OnAir Events:"),this);
-  label->setGeometry(10,241,155,19);
+  label->setGeometry(10,283,155,19);
   label->setFont(font);
   label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
 
@@ -284,24 +301,24 @@ EditReport::EditReport(QString rptname,QWidget *parent,const char *name)
   // Daypart Filter
   //
   edit_daypart_check=new QCheckBox(this);
-  edit_daypart_check->setGeometry(60,271,15,15);
+  edit_daypart_check->setGeometry(60,313,15,15);
   edit_daypart_label=
     new QLabel(edit_daypart_check,tr("Filter by Daypart"),this);
-  edit_daypart_label->setGeometry(edit_daypart_check->geometry().x()+20,271,155,19);
+  edit_daypart_label->setGeometry(edit_daypart_check->geometry().x()+20,313,155,19);
   edit_daypart_label->setFont(font);
   edit_daypart_label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
   edit_starttime_edit=new QTimeEdit(this);
-  edit_starttime_edit->setGeometry(150,292,80,20);
+  edit_starttime_edit->setGeometry(150,334,80,20);
   edit_starttime_label=new QLabel(edit_starttime_edit,tr("Start Time:"),this);
-  edit_starttime_label->setGeometry(65,292,80,20);
+  edit_starttime_label->setGeometry(65,334,80,20);
   edit_starttime_label->setFont(font);
   edit_starttime_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
 
   edit_endtime_edit=new QTimeEdit(this);
-  edit_endtime_edit->setGeometry(335,292,80,20);
+  edit_endtime_edit->setGeometry(335,334,80,20);
   edit_endtime_label=new QLabel(edit_endtime_edit,tr("End Time:"),this);
-  edit_endtime_label->setGeometry(250,292,80,20);
+  edit_endtime_label->setGeometry(250,334,80,20);
   edit_endtime_label->setFont(font);
   edit_endtime_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
 
@@ -320,7 +337,7 @@ EditReport::EditReport(QString rptname,QWidget *parent,const char *name)
   edit_service_sel=new RDListSelector(this);
   edit_service_sel->
     setGeometry((sizeHint().width()-edit_service_sel->sizeHint().width())/2,
-		331,edit_service_sel->sizeHint().width(),
+		373,edit_service_sel->sizeHint().width(),
 		edit_service_sel->sizeHint().height());
   edit_service_sel->sourceSetLabel(tr("Available Services"));
   edit_service_sel->destSetLabel(tr("Source Services"));
@@ -331,7 +348,7 @@ EditReport::EditReport(QString rptname,QWidget *parent,const char *name)
   edit_station_sel=new RDListSelector(this);
   edit_station_sel->
     setGeometry((sizeHint().width()-edit_station_sel->sizeHint().width())/2,
-		445,edit_station_sel->sizeHint().width(),
+		477,edit_station_sel->sizeHint().width(),
 		edit_station_sel->sizeHint().height());
   edit_station_sel->sourceSetLabel(tr("Available Hosts"));
   edit_station_sel->destSetLabel(tr("Source Hosts"));
@@ -342,15 +359,15 @@ EditReport::EditReport(QString rptname,QWidget *parent,const char *name)
   edit_group_sel=new RDListSelector(this);
   edit_group_sel->
     setGeometry((sizeHint().width()-edit_group_sel->sizeHint().width())/2,
-		576,edit_group_sel->sizeHint().width(),
+		593,edit_group_sel->sizeHint().width(),
 		edit_group_sel->sizeHint().height());
   edit_group_sel->sourceSetLabel(tr("Available Groups"));
   edit_group_sel->destSetLabel(tr("Allowed Groups"));
 
   edit_group_box=new QCheckBox(this);
-  edit_group_box->setGeometry(60,552,15,15);
+  edit_group_box->setGeometry(60,574,15,15);
   label=new QLabel(edit_group_box,tr("Filter by Groups"),this);
-  label->setGeometry(edit_group_box->geometry().x()+20,551,155,19);
+  label->setGeometry(edit_group_box->geometry().x()+20,573,155,19);
   label->setFont(font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
   connect(edit_group_box,SIGNAL(toggled(bool)),
@@ -371,8 +388,7 @@ EditReport::EditReport(QString rptname,QWidget *parent,const char *name)
   //  Cancel Button
   //
   button=new QPushButton(this);
-  button->setGeometry(sizeHint().width()-90,sizeHint().height()-60,
-			     80,50);
+  button->setGeometry(sizeHint().width()-90,sizeHint().height()-60,80,50);
   button->setFont(font);
   button->setText(tr("&Cancel"));
   connect(button,SIGNAL(clicked()),this,SLOT(cancelData()));
@@ -391,7 +407,11 @@ EditReport::EditReport(QString rptname,QWidget *parent,const char *name)
   edit_stationformat_edit->setText(edit_report->stationFormat());
   edit_linesperpage_spin->setValue(edit_report->linesPerPage());
   edit_path_edit->setText(edit_report->exportPath(RDReport::Linux));
+  edit_postexport_cmd_edit->
+    setText(edit_report->postExportCommand(RDReport::Linux));
   edit_winpath_edit->setText(edit_report->exportPath(RDReport::Windows));
+  edit_winpostexport_cmd_edit->
+    setText(edit_report->postExportCommand(RDReport::Windows));
   edit_traffic_box->
     setChecked(edit_report->exportTypeEnabled(RDReport::Traffic));
   edit_music_box->
@@ -482,7 +502,7 @@ EditReport::~EditReport()
 
 QSize EditReport::sizeHint() const
 {
-  return QSize(500,732);
+  return QSize(500,749);
 } 
 
 
@@ -525,7 +545,11 @@ void EditReport::okData()
   edit_report->setServiceName(edit_servicename_edit->text());
   edit_report->setStationFormat(edit_stationformat_edit->text());
   edit_report->setExportPath(RDReport::Linux,edit_path_edit->text());
+  edit_report->
+    setPostExportCommand(RDReport::Linux,edit_postexport_cmd_edit->text());
   edit_report->setExportPath(RDReport::Windows,edit_winpath_edit->text());
+  edit_report->
+    setPostExportCommand(RDReport::Windows,edit_winpostexport_cmd_edit->text());
   edit_report->
     setExportTypeEnabled(RDReport::Traffic,edit_traffic_box->isChecked());
   edit_report->
