@@ -2,9 +2,7 @@
 //
 // The full log list for RDAirPlay
 //
-//   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: list_log.cpp,v 1.105.6.11.2.1 2014/05/21 18:19:42 cvs Exp $
+//   (C) Copyright 2002-2006,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -47,8 +45,8 @@
 
 
 ListLog::ListLog(LogPlay *log,RDCae *cae,int id,bool allow_pause,
-		 QWidget *parent,const char *name)
-  : QWidget(parent,name)
+		 QWidget *parent)
+  : QWidget(parent)
 {
   list_id=id;
   list_log=log;
@@ -160,7 +158,7 @@ ListLog::ListLog(LogPlay *log,RDCae *cae,int id,bool allow_pause,
   //
   // Log List
   //
-  list_log_list=new LibListView(this,"list_log_list");
+  list_log_list=new LibListView(this);
   list_log_list->setFont(list_font);
   int y=0;
   int h=sizeHint().height()-60;
@@ -225,7 +223,7 @@ ListLog::ListLog(LogPlay *log,RDCae *cae,int id,bool allow_pause,
   //
   // List Logs Dialog
   //
-  list_logs_dialog=new ListLogs(list_log,this,"list_logs");
+  list_logs_dialog=new ListLogs(list_log,this);
 
   //
   // Time Counter Section
@@ -242,7 +240,7 @@ ListLog::ListLog(LogPlay *log,RDCae *cae,int id,bool allow_pause,
   //
   // Stop Time Counter
   //
-  list_stoptime_edit=new QLineEdit(this,"list_stoptime_edit");
+  list_stoptime_edit=new QLineEdit(this);
   list_stoptime_edit->setGeometry(407,sizeHint().height()-100,70,18);
   list_stoptime_label=new QLabel(list_stoptime_edit,tr("Next Stop:"),this);
   list_stoptime_label->setGeometry(337,sizeHint().height()-100,65,18);
@@ -257,7 +255,7 @@ ListLog::ListLog(LogPlay *log,RDCae *cae,int id,bool allow_pause,
   //
   // End Time Counter
   //
-  list_endtime_edit=new QLineEdit(this,"list_endtime_edit");
+  list_endtime_edit=new QLineEdit(this);
   list_endtime_edit->setGeometry(407,sizeHint().height()-80,70,18);
   list_endtime_label=new QLabel(list_endtime_edit,tr("Log End:"),this);
   list_endtime_label->setGeometry(337,sizeHint().height()-80,65,18);
@@ -272,7 +270,7 @@ ListLog::ListLog(LogPlay *log,RDCae *cae,int id,bool allow_pause,
   //
   // Select Button
   //
-  list_take_button=new QPushButton(this,"list_take_button");
+  list_take_button=new QPushButton(this);
   list_take_button->setGeometry(10,sizeHint().height()-55,80,50);
   list_take_button->setFont(font);
   list_take_button->setPalette(QPalette(QColor(system_button_color),QColor(system_mid_color)));
@@ -284,7 +282,7 @@ ListLog::ListLog(LogPlay *log,RDCae *cae,int id,bool allow_pause,
   //
   // Audition Head Button
   //
-  list_head_button=new QPushButton(this,"list_head_button");
+  list_head_button=new QPushButton(this);
   list_head_button->setGeometry(10,sizeHint().height()-113,80,50);
   list_head_button->setFont(font);
   list_head_button->setPalette(QPalette(QColor(system_button_color),QColor(system_mid_color)));
@@ -298,7 +296,7 @@ ListLog::ListLog(LogPlay *log,RDCae *cae,int id,bool allow_pause,
   //
   // Audition Tail Button
   //
-  list_tail_button=new QPushButton(this,"list_tail_button");
+  list_tail_button=new QPushButton(this);
   list_tail_button->setGeometry(90,sizeHint().height()-113,80,50);
   list_tail_button->setFont(font);
   list_tail_button->setPalette(QPalette(QColor(system_button_color),QColor(system_mid_color)));
@@ -312,7 +310,7 @@ ListLog::ListLog(LogPlay *log,RDCae *cae,int id,bool allow_pause,
   //
   // Play Button
   //
-  list_play_button=new QPushButton(this,"list_play_button");
+  list_play_button=new QPushButton(this);
   list_play_button->setGeometry(10,sizeHint().height()-55,80,50);
   list_play_button->setFont(font);
   list_play_button->setPalette(QPalette(QColor(system_button_color),QColor(system_mid_color)));
@@ -324,7 +322,7 @@ ListLog::ListLog(LogPlay *log,RDCae *cae,int id,bool allow_pause,
   //
   // Next Button
   //
-  list_next_button=new QPushButton(this,"list_next_button");
+  list_next_button=new QPushButton(this);
   list_next_button->setGeometry(90,sizeHint().height()-55,80,50);
   list_next_button->setFont(font);
   list_next_button->setPalette(QPalette(QColor(system_button_color),QColor(system_mid_color)));
@@ -336,7 +334,7 @@ ListLog::ListLog(LogPlay *log,RDCae *cae,int id,bool allow_pause,
   //
   // Modify Button
   //
-  list_modify_button=new QPushButton(this,"list_modify_button");
+  list_modify_button=new QPushButton(this);
   list_modify_button->setGeometry(170,sizeHint().height()-55,80,50);
   list_modify_button->setFont(font);
   list_modify_button->setPalette(QPalette(QColor(system_button_color),QColor(system_mid_color)));
@@ -348,7 +346,7 @@ ListLog::ListLog(LogPlay *log,RDCae *cae,int id,bool allow_pause,
   //
   // Scroll Button
   //
-  list_scroll_button=new QPushButton(this,"list_scroll_button");
+  list_scroll_button=new QPushButton(this);
   list_scroll_button->setGeometry(250,sizeHint().height()-55,80,50);
   list_scroll_button->setFont(font);
   list_scroll_button->setPalette(QPalette(QColor(system_button_color),QColor(system_mid_color)));
@@ -360,7 +358,7 @@ ListLog::ListLog(LogPlay *log,RDCae *cae,int id,bool allow_pause,
   //
   // Refresh Button
   //
-  list_refresh_button=new QPushButton(this,"list_refresh_button");
+  list_refresh_button=new QPushButton(this);
   list_refresh_button->setGeometry(330,sizeHint().height()-55,80,50);
   list_refresh_button->setFont(font);
   list_refresh_button->setPalette(QPalette(QColor(system_button_color),QColor(system_mid_color)));
@@ -373,7 +371,7 @@ ListLog::ListLog(LogPlay *log,RDCae *cae,int id,bool allow_pause,
   //
   // Log Load   
   //
-  list_load_button=new QPushButton(this,"list_load_button");
+  list_load_button=new QPushButton(this);
   list_load_button->setGeometry(sizeHint().width()-90,sizeHint().height()-55,
 				80,50);
   list_load_button->setFont(font);
@@ -385,7 +383,7 @@ ListLog::ListLog(LogPlay *log,RDCae *cae,int id,bool allow_pause,
   //
   // Edit Event Dialog
   //
-  list_event_edit=new EditEvent(list_log,list_cae,this,"list_event_edit");
+  list_event_edit=new EditEvent(list_log,list_cae,this);
 
   //
   // Map Slots
@@ -1419,7 +1417,7 @@ void ListLog::UpdateTimes(int removed_line,int num_lines)
 		default:
 		  if(!logline->startTime(RDLogLine::Predicted).isNull()) {
 		    next->setText(1,
-			TimeString(logline->startTime(RDLogLine::Predicted)));
+		        TimeString(logline->startTime(RDLogLine::Predicted)));
 		  }
 		  else {
 		    next->setText(1,"");
