@@ -2,9 +2,7 @@
 //
 // Edit a Rivendell Download Event
 //
-//   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: edit_download.cpp,v 1.20 2011/08/30 23:35:44 cvs Exp $
+//   (C) Copyright 2002-2005,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -42,10 +40,9 @@
 #include <edit_download.h>
 #include <globals.h>
 
-
 EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
-			   QWidget *parent,const char *name)
-  : QDialog(parent,name,true)
+			   QWidget *parent)
+  : QDialog(parent,"",true)
 {
   QString sql;
   RDSqlQuery *q;
@@ -88,10 +85,9 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   //
   // Active Button
   //
-  edit_active_button=new QCheckBox(this,"edit_active_button");
+  edit_active_button=new QCheckBox(this);
   edit_active_button->setGeometry(10,11,20,20);
-  QLabel *label=new QLabel(edit_active_button,
-		   tr("Event Active"),this,"edit_active_label");
+  QLabel *label=new QLabel(edit_active_button,tr("Event Active"),this);
   label->setGeometry(30,11,125,20);
   label->setFont(label_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
@@ -99,10 +95,9 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   //
   // Station
   //
-  edit_station_box=new QComboBox(this,"edit_station_box");
+  edit_station_box=new QComboBox(this);
   edit_station_box->setGeometry(200,10,140,23);
-  label=new QLabel(edit_station_box,tr("Location:"),this,
-				       "edit_station_label");
+  label=new QLabel(edit_station_box,tr("Location:"),this);
   label->setGeometry(125,10,70,23);
   label->setFont(label_font);
   label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
@@ -110,10 +105,9 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   //
   // Start Time
   //
-  edit_starttime_edit=new QTimeEdit(this,"edit_starttime_edit");
+  edit_starttime_edit=new QTimeEdit(this);
   edit_starttime_edit->setGeometry(sizeHint().width()-90,12,80,20);
-  label=new QLabel(edit_starttime_edit,
-		   tr("Start Time:"),this,"edit_starttime_label");
+  label=new QLabel(edit_starttime_edit,tr("Start Time:"),this);
   label->setGeometry(sizeHint().width()-175,12,80,20);
   label->setFont(label_font);
   label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
@@ -121,11 +115,10 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   //
   // Description
   //
-  edit_description_edit=new QLineEdit(this,"edit_description_edit");
+  edit_description_edit=new QLineEdit(this);
   edit_description_edit->setGeometry(115,43,sizeHint().width()-125,20);
   edit_description_edit->setValidator(validator);
-  label=new QLabel(edit_description_edit,
-		   tr("Description:"),this,"edit_description_label");
+  label=new QLabel(edit_description_edit,tr("Description:"),this);
   label->setGeometry(10,43,100,20);
   label->setFont(label_font);
   label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
@@ -133,13 +126,13 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   //
   // Url
   //
-  edit_url_edit=new QLineEdit(this,"edit_url_edit");
+  edit_url_edit=new QLineEdit(this);
   edit_url_edit->setGeometry(115,70,sizeHint().width()-125,20);
   edit_url_edit->setMaxLength(255);
   edit_url_edit->setValidator(validator);
   connect(edit_url_edit,SIGNAL(textChanged(const QString &)),
 	  this,SLOT(urlChangedData(const QString &)));
-  label=new QLabel(edit_url_edit,tr("Url:"),this,"edit_url_label");
+  label=new QLabel(edit_url_edit,tr("Url:"),this);
   label->setGeometry(10,70,100,20);
   label->setFont(label_font);
   label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
@@ -147,12 +140,11 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   //
   // Username
   //
-  edit_username_edit=new QLineEdit(this,"edit_username_edit");
+  edit_username_edit=new QLineEdit(this);
   edit_username_edit->setGeometry(115,97,150,20);
   edit_username_edit->setMaxLength(64);
   edit_username_edit->setValidator(validator);
-  edit_username_label=new QLabel(edit_username_edit,
-		   tr("Username:"),this,"edit_username_label");
+  edit_username_label=new QLabel(edit_username_edit,tr("Username:"),this);
   edit_username_label->setGeometry(10,97,100,20);
   edit_username_label->setFont(label_font);
   edit_username_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
@@ -160,13 +152,12 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   //
   // Password
   //
-  edit_password_edit=new QLineEdit(this,"edit_password_edit");
+  edit_password_edit=new QLineEdit(this);
   edit_password_edit->setGeometry(360,97,sizeHint().width()-370,20);
   edit_password_edit->setEchoMode(QLineEdit::Password);
   edit_password_edit->setMaxLength(64);
   edit_username_edit->setValidator(validator);
-  edit_password_label=new QLabel(edit_password_edit,
-		   tr("Password:"),this,"edit_password_label");
+  edit_password_label=new QLabel(edit_password_edit,tr("Password:"),this);
   edit_password_label->setGeometry(275,97,80,20);
   edit_password_label->setFont(label_font);
   edit_password_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
@@ -174,15 +165,14 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   //
   // Destination
   //
-  edit_destination_edit=new QLineEdit(this,"edit_destination_edit");
+  edit_destination_edit=new QLineEdit(this);
   edit_destination_edit->setGeometry(115,124,sizeHint().width()-195,20);
   edit_destination_edit->setReadOnly(true);
-  label=new QLabel(edit_destination_edit,
-		   tr("Destination:"),this,"edit_destination_label");
+  label=new QLabel(edit_destination_edit,tr("Destination:"),this);
   label->setGeometry(10,127,100,19);
   label->setFont(label_font);
   label->setAlignment(AlignRight|ShowPrefix);
-  QPushButton *button=new QPushButton(this,"destination_button");
+  QPushButton *button=new QPushButton(this);
   button->setGeometry(sizeHint().width()-70,122,60,24);
   button->setFont(day_font);
   button->setText(tr("&Select"));
@@ -191,12 +181,11 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   //
   // Channels
   //
-  edit_channels_box=new QComboBox(this,"edit_channels_box");
+  edit_channels_box=new QComboBox(this);
   edit_channels_box->setGeometry(190,149,40,20);
   edit_channels_box->insertItem("1");
   edit_channels_box->insertItem("2");
-  label=
-    new QLabel(edit_channels_box,tr("Channels:"),this,"edit_autotrim_label");
+  label=new QLabel(edit_channels_box,tr("Channels:"),this);
   label->setGeometry(120,149,70,20);
   label->setFont(label_font);
   label->setAlignment(AlignVCenter|AlignLeft);
@@ -204,7 +193,7 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   //
   // Autotrim Controls
   //
-  edit_autotrim_box=new QCheckBox(this,"edit_autotrim_box");
+  edit_autotrim_box=new QCheckBox(this);
   edit_autotrim_box->setGeometry(120,175,15,15);
   connect(edit_autotrim_box,SIGNAL(toggled(bool)),
 	  this,SLOT(autotrimToggledData(bool)));
@@ -212,16 +201,14 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   label->setGeometry(140,173,80,20);
   label->setFont(label_font);
   label->setAlignment(AlignVCenter|AlignLeft);
-  edit_autotrim_spin=new QSpinBox(this,"edit_autotrim_spin");
+  edit_autotrim_spin=new QSpinBox(this);
   edit_autotrim_spin->setGeometry(265,173,40,20);
   edit_autotrim_spin->setRange(-99,-1);
-  edit_autotrim_label=
-    new QLabel(edit_autotrim_spin,tr("Level:"),this,"edit_autotrim_label");
+  edit_autotrim_label=new QLabel(edit_autotrim_spin,tr("Level:"),this);
   edit_autotrim_label->setGeometry(220,173,40,20);
   edit_autotrim_label->setFont(label_font);
   edit_autotrim_label->setAlignment(AlignVCenter|AlignRight);
-  edit_autotrim_unit=
-    new QLabel(edit_autotrim_spin,tr("dBFS"),this,"edit_autotrim_unit");
+  edit_autotrim_unit=new QLabel(edit_autotrim_spin,tr("dBFS"),this);
   edit_autotrim_unit->setGeometry(310,173,40,20);
   edit_autotrim_unit->setFont(label_font);
   edit_autotrim_unit->setAlignment(AlignVCenter|AlignLeft);
@@ -229,7 +216,7 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   //
   // Normalize Controls
   //
-  edit_normalize_box=new QCheckBox(this,"edit_normalize_box");
+  edit_normalize_box=new QCheckBox(this);
   edit_normalize_box->setGeometry(120,199,15,15);
   connect(edit_normalize_box,SIGNAL(toggled(bool)),
 	  this,SLOT(normalizeToggledData(bool)));
@@ -237,16 +224,14 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   label->setGeometry(140,197,80,20);
   label->setFont(label_font);
   label->setAlignment(AlignVCenter|AlignLeft);
-  edit_normalize_spin=new QSpinBox(this,"edit_normalize_spin");
+  edit_normalize_spin=new QSpinBox(this);
   edit_normalize_spin->setGeometry(265,197,40,20);
   edit_normalize_spin->setRange(-99,-1);
-  edit_normalize_label=
-    new QLabel(edit_normalize_spin,tr("Level:"),this,"edit_normalize_label");
+  edit_normalize_label=new QLabel(edit_normalize_spin,tr("Level:"),this);
   edit_normalize_label->setGeometry(220,197,40,20);
   edit_normalize_label->setFont(label_font);
   edit_normalize_label->setAlignment(AlignVCenter|AlignRight);
-  edit_normalize_unit=
-    new QLabel(edit_normalize_spin,tr("dBFS"),this,"edit_normalize_unit");
+  edit_normalize_unit=new QLabel(edit_normalize_spin,tr("dBFS"),this);
   edit_normalize_unit->setGeometry(310,197,40,20);
   edit_normalize_unit->setFont(label_font);
   edit_normalize_unit->setAlignment(AlignVCenter|AlignLeft);
@@ -254,10 +239,9 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   //
   // Export Metadata Box
   //
-  edit_metadata_box=new QCheckBox(this,"edit_metadata_box");
+  edit_metadata_box=new QCheckBox(this);
   edit_metadata_box->setGeometry(120,222,15,15);
-  label=new QLabel(edit_metadata_box,tr("Update Library Metadata"),
-		   this,"metadata_check_label");
+  label=new QLabel(edit_metadata_box,tr("Update Library Metadata"),this);
   label->setGeometry(140,222,160,20);
   label->setFont(label_font);
   label->setAlignment(AlignLeft|AlignVCenter);
@@ -265,7 +249,7 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   //
   // Button Label
   //
-  label=new QLabel(tr("Active Days"),this,"active_days_label");
+  label=new QLabel(tr("Active Days"),this);
   label->setGeometry(47,254,90,19);
   label->setFont(label_font);
   label->setAlignment(AlignHCenter|ShowPrefix);
@@ -273,10 +257,9 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   //
   // Monday Button
   //
-  edit_mon_button=new QCheckBox(this,"edit_mon_button");
+  edit_mon_button=new QCheckBox(this);
   edit_mon_button->setGeometry(20,273,20,20);
-  label=new QLabel(edit_mon_button,
-		   tr("Monday"),this,"edit_mon_label");
+  label=new QLabel(edit_mon_button,tr("Monday"),this);
   label->setGeometry(40,273,115,20);
   label->setFont(day_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
@@ -284,10 +267,9 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   //
   // Tuesday Button
   //
-  edit_tue_button=new QCheckBox(this,"edit_tue_button");
+  edit_tue_button=new QCheckBox(this);
   edit_tue_button->setGeometry(115,273,20,20);
-  label=new QLabel(edit_tue_button,
-		   tr("Tuesday"),this,"edit_tue_label");
+  label=new QLabel(edit_tue_button,tr("Tuesday"),this);
   label->setGeometry(135,273,115,20);
   label->setFont(day_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
@@ -295,10 +277,9 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   //
   // Wednesday Button
   //
-  edit_wed_button=new QCheckBox(this,"edit_wed_button");
+  edit_wed_button=new QCheckBox(this);
   edit_wed_button->setGeometry(215,273,20,20);
-  label=new QLabel(edit_wed_button,
-		   tr("Wednesday"),this,"edit_wed_label");
+  label=new QLabel(edit_wed_button,tr("Wednesday"),this);
   label->setGeometry(235,273,115,20);
   label->setFont(day_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
@@ -306,10 +287,9 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   //
   // Thursday Button
   //
-  edit_thu_button=new QCheckBox(this,"edit_thu_button");
+  edit_thu_button=new QCheckBox(this);
   edit_thu_button->setGeometry(335,273,20,20);
-  label=new QLabel(edit_thu_button,
-		   tr("Thursday"),this,"edit_thu_label");
+  label=new QLabel(edit_thu_button,tr("Thursday"),this);
   label->setGeometry(355,273,115,20);
   label->setFont(day_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
@@ -317,10 +297,9 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   //
   // Friday Button
   //
-  edit_fri_button=new QCheckBox(this,"edit_fri_button");
+  edit_fri_button=new QCheckBox(this);
   edit_fri_button->setGeometry(440,273,20,20);
-  label=new QLabel(edit_fri_button,
-		   tr("Friday"),this,"edit_fri_label");
+  label=new QLabel(edit_fri_button,tr("Friday"),this);
   label->setGeometry(460,273,40,20);
   label->setFont(day_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
@@ -328,10 +307,9 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   //
   // Saturday Button
   //
-  edit_sat_button=new QCheckBox(this,"edit_sat_button");
+  edit_sat_button=new QCheckBox(this);
   edit_sat_button->setGeometry(130,298,20,20);
-  label=new QLabel(edit_sat_button,
-		   tr("Saturday"),this,"edit_sat_label");
+  label=new QLabel(edit_sat_button,tr("Saturday"),this);
   label->setGeometry(150,298,60,20);
   label->setFont(day_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
@@ -339,10 +317,9 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   //
   // Sunday Button
   //
-  edit_sun_button=new QCheckBox(this,"edit_sun_button");
+  edit_sun_button=new QCheckBox(this);
   edit_sun_button->setGeometry(300,298,20,20);
-  label=new QLabel(edit_sun_button,
-		   tr("Sunday"),this,"edit_sun_label");
+  label=new QLabel(edit_sun_button,tr("Sunday"),this);
   label->setGeometry(320,298,60,20);
   label->setFont(day_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
@@ -350,10 +327,9 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   //
   // OneShot Button
   //
-  edit_oneshot_box=new QCheckBox(this,"edit_oneshot_box");
+  edit_oneshot_box=new QCheckBox(this);
   edit_oneshot_box->setGeometry(20,335,15,15);
-  label=new QLabel(edit_oneshot_box,
-		   tr("Make OneShot"),this,"edit_oneshot_label");
+  label=new QLabel(edit_oneshot_box,tr("Make OneShot"),this);
   label->setGeometry(40,333,115,20);
   label->setFont(label_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
@@ -361,16 +337,14 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   //
   // Event Offset
   //
-  edit_eventoffset_spin=new QSpinBox(this,"edit_eventoffset_spin");
+  edit_eventoffset_spin=new QSpinBox(this);
   edit_eventoffset_spin->setGeometry(245,333,45,20);
   edit_eventoffset_spin->setRange(-30,30);
-  label=new QLabel(edit_eventoffset_spin,tr("Event Offset:"),
-		   this,"edit_eventoffset_label");
+  label=new QLabel(edit_eventoffset_spin,tr("Event Offset:"),this);
   label->setGeometry(140,333,100,20);
   label->setFont(label_font);
   label->setAlignment(AlignVCenter|AlignRight);
-  label=new QLabel(edit_eventoffset_spin,tr("days"),
-		   this,"edit_eventoffset_unit");
+  label=new QLabel(edit_eventoffset_spin,tr("days"),this);
   label->setGeometry(295,333,40,20);
   label->setFont(label_font);
   label->setAlignment(AlignVCenter|AlignLeft);
@@ -378,7 +352,7 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   //
   //  Save As Button
   //
-  button=new QPushButton(this,"saveas_button");
+  button=new QPushButton(this);
   button->setGeometry(sizeHint().width()-300,sizeHint().height()-60,80,50);
   button->setFont(button_font);
   button->setText(tr("&Save As\nNew"));
@@ -390,7 +364,7 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   //
   //  Ok Button
   //
-  button=new QPushButton(this,"ok_button");
+  button=new QPushButton(this);
   button->setGeometry(sizeHint().width()-180,sizeHint().height()-60,80,50);
   button->setDefault(true);
   button->setFont(button_font);
@@ -400,7 +374,7 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   //
   //  Cancel Button
   //
-  button=new QPushButton(this,"cancel_button");
+  button=new QPushButton(this);
   button->setGeometry(sizeHint().width()-90,sizeHint().height()-60,80,50);
   button->setFont(button_font);
   button->setText(tr("&Cancel"));
