@@ -2,7 +2,7 @@
 //
 // Edit a Rivendell Log
 //
-//   (C) Copyright 2002-2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2017 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -62,7 +62,8 @@
 #include "../icons/mic16.xpm"
 #include "../icons/traffic.xpm"
 
-EditLog::EditLog(QString logname,vector<RDLogLine> *clipboard,
+EditLog::EditLog(QString logname,QString *filter,QString *group,
+		 QString *schedcode,vector<RDLogLine> *clipboard,
 		 vector<QString> *new_logs,QWidget *parent)
   : QDialog(parent,"",true)
 {
@@ -73,6 +74,9 @@ EditLog::EditLog(QString logname,vector<RDLogLine> *clipboard,
   QColor system_button_color = palette().active().button();
 
   edit_logname=logname;
+  edit_filter=filter;
+  edit_group=group;
+  edit_schedcode=schedcode;
   edit_clipboard=clipboard;
   edit_newlogs=new_logs;
   edit_default_trans=RDLogLine::Play;
@@ -101,6 +105,8 @@ EditLog::EditLog(QString logname,vector<RDLogLine> *clipboard,
   //
   // Create Fonts
   //
+  QFont modified_font=QFont("Helvetica",18,QFont::Bold);
+  modified_font.setPixelSize(18);
   QFont button_font=QFont("Helvetica",12,QFont::Bold);
   button_font.setPixelSize(12);
   QFont label_font=QFont("Helvetica",12,QFont::Bold);
@@ -109,7 +115,6 @@ EditLog::EditLog(QString logname,vector<RDLogLine> *clipboard,
   title_font.setPixelSize(12);
   QFont length_font=QFont("Helvetica",10,QFont::Bold);
   length_font.setPixelSize(10);
-
   
   //
   // Create Icons
@@ -143,6 +148,10 @@ EditLog::EditLog(QString logname,vector<RDLogLine> *clipboard,
   //
   // Log Name
   //
+  edit_modified_label=new QLabel(this);
+  edit_modified_label->setBackgroundColor(QColor(system_mid_color));
+  edit_modified_label->setAlignment(Qt::AlignCenter|Qt::AlignVCenter);
+  edit_modified_label->setFont(modified_font);
   edit_logname_label=new QLabel(logname,this);
   edit_logname_label->setBackgroundColor(QColor(system_mid_color));
   edit_logname_label->setAlignment(AlignLeft|AlignVCenter);
@@ -201,10 +210,14 @@ EditLog::EditLog(QString logname,vector<RDLogLine> *clipboard,
   edit_purgedate_edit=new QDateEdit(this);
   edit_purgedate_button=new QPushButton(tr("Select"),this);
   edit_purgedate_button->setFont(label_font);
+  connect(edit_purgedate_box,SIGNAL(toggled(bool)),
+	  this,SLOT(purgeDateToggledData(bool)));
   connect(edit_purgedate_box,SIGNAL(toggled(bool)),
 	  edit_purgedate_edit,SLOT(setEnabled(bool)));
   connect(edit_purgedate_box,SIGNAL(toggled(bool)),
 	  edit_purgedate_button,SLOT(setEnabled(bool)));
+  connect(edit_purgedate_edit,SIGNAL(valueChanged(const QDate &)),
+	  this,SLOT(purgeDateChangedData(const QDate &)));
   connect(edit_purgedate_button,SIGNAL(clicked()),
 	  this,SLOT(selectPurgeDateData()));
 
@@ -232,6 +245,8 @@ EditLog::EditLog(QString logname,vector<RDLogLine> *clipboard,
     new QLabel(edit_autorefresh_box,tr("Enable AutoRefresh:"),this);
   edit_autorefresh_label->setFont(label_font);
   edit_autorefresh_label->setAlignment(AlignRight|AlignVCenter);  
+  connect(edit_autorefresh_box,SIGNAL(activated(int)),
+	  this,SLOT(autorefreshChangedData(int)));
 
   //
   // Start Date
@@ -434,6 +449,7 @@ EditLog::EditLog(QString logname,vector<RDLogLine> *clipboard,
   edit_save_button=new QPushButton(this);
   edit_save_button->setFont(button_font);
   edit_save_button->setText(tr("&Save"));
+  edit_save_button->setDisabled(true);
   connect(edit_save_button,SIGNAL(clicked()),this,SLOT(saveData()));
 
   //
@@ -549,7 +565,7 @@ EditLog::EditLog(QString logname,vector<RDLogLine> *clipboard,
   }
   RefreshList();
   serviceActivatedData(edit_service_box->currentText());
-  edit_changed=false;
+  SetLogModified(false);
   UpdateTracks();
 
   //
@@ -611,7 +627,19 @@ QSizePolicy EditLog::sizePolicy() const
 
 void EditLog::descriptionChangedData(const QString &)
 {
-  edit_changed=true;
+  SetLogModified(true);
+}
+
+
+void EditLog::purgeDateChangedData(const QDate &date)
+{
+  SetLogModified(true);
+}
+
+
+void EditLog::purgeDateToggledData(bool state)
+{
+  SetLogModified(true);
 }
 
 
@@ -621,14 +649,14 @@ void EditLog::selectPurgeDateData()
   RDDateDialog *d=new RDDateDialog(2008,QDate::currentDate().year()+5,this);
   if(d->exec(&date)==0) {
     edit_purgedate_edit->setDate(date);
-    edit_changed=true;
+    SetLogModified(true);
   }
 }
 
 
 void EditLog::serviceActivatedData(const QString &svcname)
 {
-  edit_changed=true;
+  SetLogModified(true);
   edit_group_list.loadSvc(svcname);
   if(!ValidateSvc()) {
     QMessageBox::warning(this,tr("Invalid Carts"),
@@ -644,7 +672,7 @@ void EditLog::startDateEnabledData(bool state)
   }
   edit_startdate_edit->setEnabled(state);
   edit_startdate_label->setEnabled(state);
-  edit_changed=true;
+  SetLogModified(true);
 }
 
 
@@ -655,13 +683,19 @@ void EditLog::endDateEnabledData(bool state)
   }
   edit_enddate_edit->setEnabled(state);
   edit_enddate_label->setEnabled(state);
-  edit_changed=true;
+  SetLogModified(true);
 }
 
 
 void EditLog::dateValueChangedData(const QDate &)
 {
-  edit_changed=true;
+  SetLogModified(true);
+}
+
+
+void EditLog::autorefreshChangedData(int index)
+{
+  SetLogModified(true);
 }
 
 
@@ -682,13 +716,13 @@ void EditLog::insertCartButtonData()
   edit_log_event->logLine(line)->setFadeupGain(-3000);
   edit_log_event->logLine(line)->setFadedownGain(-3000);
   EditLogLine *edit=
-new EditLogLine(edit_log_event->logLine(line),&edit_filter,&edit_group,
-				    edit_service_box->currentText(),
-				    &edit_group_list,edit_log_event,line,this);
+    new EditLogLine(edit_log_event->logLine(line),edit_filter,edit_group,
+		    edit_schedcode,edit_service_box->currentText(),
+		    &edit_group_list,edit_log_event,line,this);
   int ret=edit->exec();
   if(ret>=0) {
     edit_log_event->refresh(line);
-    edit_changed=true;
+    SetLogModified(true);
   }
   else {
     edit_log_event->remove(line,1);
@@ -726,7 +760,7 @@ void EditLog::insertMarkerButtonData()
 	ret=edit_marker->exec();
 	if(ret>=0) {
 	  edit_log_event->refresh(line);
-	  edit_changed=true;
+	  SetLogModified(true);
 	}
 	else {
 	  edit_log_event->remove(line,1);
@@ -743,7 +777,7 @@ void EditLog::insertMarkerButtonData()
 	ret=edit_track->exec();
 	if(ret>=0) {
 	  edit_log_event->refresh(line);
-	  edit_changed=true;
+	  SetLogModified(true);
 	}
 	else {
 	  edit_log_event->remove(line,1);
@@ -758,7 +792,7 @@ void EditLog::insertMarkerButtonData()
 	ret=edit_chain->exec();
 	if(ret>=0) {
 	  edit_log_event->refresh(line);
-	  edit_changed=true;
+	  SetLogModified(true);
 	}
 	else {
 	  edit_log_event->remove(line,1);
@@ -827,12 +861,13 @@ void EditLog::editButtonData()
   switch(edit_log_event->logLine(line)->type()) {
       case RDLogLine::Cart:
       case RDLogLine::Macro:
-	edit_cart=new EditLogLine(edit_log_event->logLine(line),&edit_filter,
-				  &edit_group,edit_service_box->currentText(),
-				  &edit_group_list,edit_log_event,line,this);
+	edit_cart=
+	  new EditLogLine(edit_log_event->logLine(line),edit_filter,edit_group,
+			  edit_schedcode,edit_service_box->currentText(),
+			  &edit_group_list,edit_log_event,line,this);
 	if(edit_cart->exec()>=0) {
 	  edit_log_event->refresh(item->text(14).toInt());
-	  edit_changed=true;
+	  SetLogModified(true);
 	}
 	delete edit_cart;
 	break;
@@ -840,7 +875,7 @@ void EditLog::editButtonData()
       case RDLogLine::Marker:
 	edit_marker=new EditMarker(edit_log_event->logLine(line),this);
 	if(edit_marker->exec()>=0) {
-	  edit_changed=true;
+	  SetLogModified(true);
 	}
 	delete edit_marker;
 	break;
@@ -848,7 +883,7 @@ void EditLog::editButtonData()
       case RDLogLine::Track:
 	edit_track=new EditTrack(edit_log_event->logLine(line),this);
 	if(edit_track->exec()>=0) {
-	  edit_changed=true;
+	  SetLogModified(true);
 	}
 	delete edit_track;
 	break;
@@ -856,7 +891,7 @@ void EditLog::editButtonData()
       case RDLogLine::Chain:
 	edit_chain=new EditChain(edit_log_event->logLine(line),this);
 	if(edit_chain->exec()>=0) {
-	  edit_changed=true;
+	  SetLogModified(true);
 	}
 	delete edit_chain;
 	break;
@@ -903,7 +938,7 @@ void EditLog::upButtonData()
   sscanf((const char *)item->text(13),"%u",&id);
   edit_log_event->move(item->text(14).toInt(),
 		       item->text(14).toInt()-1);
-  edit_changed=true;
+  SetLogModified(true);
   RefreshList();
   SelectRecord(id);
   UpdateSelection();
@@ -921,7 +956,7 @@ void EditLog::downButtonData()
   int id=item->text(13).toInt();
   edit_log_event->move(item->text(14).toInt(),
 		       item->text(14).toInt()+1);
-  edit_changed=true;
+  SetLogModified(true);
   RefreshList();
   SelectRecord(id);
   UpdateSelection();
@@ -958,7 +993,7 @@ void EditLog::pasteButtonData()
     edit_log_event->logLine(line+i)->setSource(RDLogLine::Manual);
     edit_clipboard->at(i).clearExternalData();
   }
-  edit_changed=true;
+  SetLogModified(true);
   RefreshList();
   UpdateTracks();
   SelectRecord(id);
@@ -987,7 +1022,7 @@ void EditLog::cartDroppedData(int line,RDLogLine *ll)
   edit_log_event->logLine(line)->setFadeupGain(-3000);
   edit_log_event->logLine(line)->setFadedownGain(-3000);
   edit_log_event->refresh(line);
-  edit_changed=true;
+  SetLogModified(true);
   if(appended) {
     item=(RDListViewItem *)edit_log_list->lastItem();
     item->setText(14,QString().sprintf("%d",item->text(14).toInt()+1));
@@ -1023,7 +1058,7 @@ void EditLog::saveData()
     return;
   }
   edit_log_event->save();
-  edit_changed=false;
+  SetLogModified(false);
   edit_log->setAutoRefresh(edit_autorefresh_box->currentItem()==0);
   edit_log->
     setModifiedDatetime(QDateTime(QDate::currentDate(),QTime::currentTime()));
@@ -1087,7 +1122,7 @@ ORIGIN_DATETIME=NOW(),LINK_DATETIME=NOW(),SERVICE=\"%s\"",
   }
   delete log;
   RefreshList();
-  edit_changed=false;
+  SetLogModified(false);
   edit_deleted_tracks.clear();
 }
 
@@ -1114,14 +1149,16 @@ void EditLog::reportsData()
 
 void EditLog::okData()
 {
-  if(!ValidateSvc()) {
-    if(QMessageBox::warning(this,tr("Invalid Carts"),
-			    tr("The log contains carts that are disabled\nfor the selected service!\n\nDo you still want to save?"),QMessageBox::Yes,QMessageBox::No)==QMessageBox::No) {
-      return;
+  if(edit_changed) {
+    if(!ValidateSvc()) {
+      if(QMessageBox::warning(this,tr("Invalid Carts"),
+			      tr("The log contains carts that are disabled\nfor the selected service!\n\nDo you still want to save?"),QMessageBox::Yes,QMessageBox::No)==QMessageBox::No) {
+	return;
+      }
     }
+    SaveLog();
+    DeleteTracks();
   }
-  SaveLog();
-  DeleteTracks();
 #ifndef WIN32
   edit_player->stop();
 #endif  // WIN32
@@ -1174,7 +1211,8 @@ void EditLog::closeEvent(QCloseEvent *e)
 void EditLog::resizeEvent(QResizeEvent *e)
 {
   edit_logname_label->setGeometry(155,11,size().width()-500,18);
-  edit_logname_label_label->setGeometry(70,11,80,18);
+  edit_logname_label_label->setGeometry(80,11,70,18);
+  edit_modified_label->setGeometry(60,14,20,18);
   edit_origin_label->setGeometry(size().width()-300,11,200,18);
   edit_origin_label_label->setGeometry(size().width()-345,11,40,18);
   edit_track_label->setGeometry(size().width()-425,11,40,18);
@@ -1276,7 +1314,7 @@ void EditLog::DeleteLines(int line,int count)
       next->setSelected(true);
     }
     edit_log_event->remove(line,count);
-    edit_changed=true;
+    SetLogModified(true);
     RenumberList(line);
   }
   UpdateTracks();
@@ -1328,6 +1366,18 @@ void EditLog::RefreshLine(RDListViewItem *item)
 	break;
 
       default:
+	if(logline->
+	   startTime(RDLogLine::Predicted).isNull()) {
+	  item->setText(1,edit_log_event->
+			blockStartTime(line).
+			toString("hh:mm:ss.zzz").left(10));
+	}
+	else {
+	  item->setText(1,edit_log_event->
+			logLine(line)->startTime(RDLogLine::Predicted).
+			toString("hh:mm:ss.zzz").left(10));
+	}
+	/*
 	if(logline->
 	   startTime(RDLogLine::Logged).isNull()) {
 	  item->setText(1,edit_log_event->
@@ -1339,6 +1389,7 @@ void EditLog::RefreshLine(RDListViewItem *item)
 			logLine(line)->startTime(RDLogLine::Logged).
 			toString("hh:mm:ss.zzz").left(10));
 	}
+	*/
 	break;
   }
   switch(logline->transType()) {
@@ -1744,3 +1795,18 @@ void EditLog::LoadClipboard(bool clear_ext)
     next=next->nextSibling();
   }
 }
+
+
+void EditLog::SetLogModified(bool state)
+{
+  if(state!=edit_changed) {
+    if(state) {
+      edit_modified_label->setText("*");
+    }
+    else {
+      edit_modified_label->setText("");
+    }
+    edit_save_button->setEnabled(state);
+    edit_changed=state;
+  }
+}
