@@ -187,6 +187,10 @@ Você quer salvar?</translation>
         <source>That code is already in use!</source>
         <translation>Este Código já está em uso!</translation>
     </message>
+    <message>
+        <source>&amp;Clone</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditEvent</name>
@@ -518,6 +522,10 @@ Você quer sobreescrêve-lo?</translation>
         <source>IMPORT</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>and code</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditEventLine</name>
