@@ -2,9 +2,7 @@
 //
 // A Qt-based application for display info about ASI cards.
 //
-//   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
-//
-//    $Id: rdhpiinfo.h,v 1.5.6.1 2012/05/04 14:56:23 cvs Exp $
+//   (C) Copyright 2002-2005,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,14 +18,15 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-
 #ifndef RDHPIINFO_H
 #define RDHPIINFO_H
 
 #include <qwidget.h>
 #include <qcombobox.h>
 #include <qlabel.h>
+#include <qlineedit.h>
 #include <qpushbutton.h>
+#include <qtimer.h>
 
 #include <asihpi/hpi.h>
 #if HPI_VER < 0x040600
@@ -41,7 +40,7 @@ class MainWidget : public QWidget
 {
   Q_OBJECT
  public:
-  MainWidget(QWidget *parent=0,const char *name=0);
+  MainWidget(QWidget *parent=0);
   ~MainWidget();
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
@@ -49,19 +48,24 @@ class MainWidget : public QWidget
  private slots:
   void nameActivatedData(int id);
   void changeModeData();
+  void utilizationData();
+  void updateDspUtilization();
 
  private:
   void LoadAdapters();
-  void HpiErr(hpi_err_t err,const char *func_name=0) const;
+  hpi_err_t HpiErr(hpi_err_t err,const char *func_name=0) const;
   QLabel *info_name_label;
   QComboBox *info_name_box;
+  QLabel *info_utilization_label;
+  QLineEdit *info_utilization_edit;
+  QPushButton *info_utilization_button;
   QLabel *info_index_label;
   QLabel *info_serial_label;
   QLabel *info_istreams_label;
   QLabel *info_ostreams_label;
   QLabel *info_dsp_label;
   QLabel *info_adapter_label;
-  QLabel *info_mode_label;
+  QLineEdit *info_mode_edit;
   QPushButton *info_changemode_button;
   uint32_t hpi_version;
   QString hpi_name[HPI_MAX_ADAPTERS];
@@ -73,6 +77,9 @@ class MainWidget : public QWidget
   uint32_t hpi_serial[HPI_MAX_ADAPTERS];
   uint16_t hpi_type[HPI_MAX_ADAPTERS];
   uint32_t hpi_mode[HPI_MAX_ADAPTERS];
+  hpi_handle_t hpi_profile[HPI_MAX_ADAPTERS];
+  uint16_t hpi_profile_quan[HPI_MAX_ADAPTERS];
+  QTimer *hpi_profile_timer;
 };
 
 
