@@ -2,9 +2,7 @@
 //
 // A utility for sending RML Commands
 //
-//   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rmlsend.cpp,v 1.7.8.2 2013/03/13 20:10:40 cvs Exp $
+//   (C) Copyright 2002-2005,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -27,6 +25,7 @@
 #endif
 
 #include <qapplication.h>
+#include <qwindowsstyle.h>
 #include <qwidget.h>
 #include <qpushbutton.h>
 #include <qlineedit.h>
@@ -71,9 +70,8 @@
 //
 RDCmdSwitch *rdcmdswitch=NULL;
 
-
-MainWidget::MainWidget(QWidget *parent,const char *name)
-  :QMainWindow(parent,name)
+MainWidget::MainWidget(QWidget *parent)
+  :QMainWindow(parent)
 {
   //
   // Set Window Size
@@ -511,7 +509,7 @@ int main(int argc,char *argv[])
   if(cli_mode) {
 #ifndef WIN32
     QApplication a(argc,argv,false);
-    new MainObject(NULL,"main");
+    new MainObject();
     return a.exec();
 #endif  // WIN32
   }
@@ -553,7 +551,7 @@ int main(int argc,char *argv[])
     //
     // Start Event Loop
     //
-    MainWidget *w=new MainWidget(NULL,"main");
+    MainWidget *w=new MainWidget();
     a.setMainWidget(w);
     w->show();
     return a.exec();
